#############################################################################
#
# LOGREP - Logfile Extraction And Reporting System                          
# Copyright (C) 2002 Tevfik Karaglle                                   
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
#
#############################################################################

#################
#
# logrep - downloads logfiles and generates html reports daily from target machines
# Command line parameters:
#
#	-m <mode> -  -daily-, -snapshot-
#
# v1.2 - Support for -s option is added	
# v1.1 - Support for Logrep server on Linux, oct 2002, TK
#	 Logfiles is downloaded from logrep subdirectory
#	 Supports compressed (gz) logfiles
#	 Favorites pages, commandline parameter change
# v1.0 - initial version, jun 2002, Tevfik K. (tevfik@itefix.no)
#

use Getopt::Std;

# Get command line parameter 
getopts("m:") or die $!;
$mode = lc ($opt_m);

die "Parameter can be -daily- or -snapshot-!!" if ($mode ne "daily" && $mode ne "snapshot");

do "parameters.pl";

($sec,$min,$hour,$mday,$mon,$year,$wday,$yday) = gmtime();

$year += 1900; 		#4-digit year
$mon++; 			# make relative to 1

# Logfile logrep operations
$logfile = sprintf "$logdir/logrep/%02d%02d.log", $mon, $mday;

$i = 0;

foreach (@nodes) {

	$system = $nodes [$i][0];
	$node = $nodes [$i][1];
	$subset = $nodes [$i][2];
	$i++;

	# Generate pathinfo	
	$logpath = "$rootpath/log/$system/$node/" . (($mode eq "daily") ? $year : "snapshot");
	$localpath = sprintf ("$logpath/%02d%02d", $mon, $mday);
	$localpathgz = "$localpath.gz";
	$filename = $system .(($mode eq "daily") ? ".full" : ".snapshot");
	$remotepath = "$login\@$node:logrep/$filename.gz";
	
	#DEBUG! print "$remotepath, $localpath\n";
	system "echo '*l*o*g*r*e*p* - mode $mode' >> $logfile";
	system "echo Download logfile from $remotepath to $localpathgz >> $logfile";

	# download logfile
	system "scp -q -i $keyfile $remotepath $localpathgz >> $logfile";
	
	next if !(-e $localpathgz); # Local logfile doesn't exist. Go to next!
	
	# web directory for html reports
	$webdirnode = $webdir . "/$system/$node/$mode";
	
	system "echo Generate html reports in $webdirnode >> $logfile";
	# Generate html reports
	system "gzip -d $localpathgz";
	$scmd = (defined $subset) ? "-s $subset" : "";
	system "perl $progdir/module-$system.pl -l $localpath -w $webdirnode $scmd >> $logfile";
	system "gzip $localpath";	
	
	system "echo Generate favorites page in $webdir >> $logfile";
	system "perl $progdir/make-favorites.pl -m $mode";
	
	system "echo ++++++++++ >> $logfile";
}
