#############################################################################
#
# LOGREP - Logfile Extraction And Reporting System                          
# Copyright (C) 2002 Tevfik Karaglle                                   
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
#
#############################################################################

#########
#
# make-favorites.pl - Generate favorites page (graphs, reports and access to all nodes)
#
# option -m : -daily- generates favorites for daily reports
#			  -snapshot- generates favorites for snapshot reports
# v1.0 - Initial version, jun 02, Tevfik K. (tevfik@itefix.no)

use CGI qw/*table/;
use Getopt::Std;

getopts("m:") or die $!;
$mode = lc ($opt_m);

die "Parameter can be -daily- or -snapshot-!!" if ($mode ne "daily" && $mode ne "snapshot");

do "parameters.pl";
do "lib1.pl";

$q = new CGI;
$indexpage = "index-$mode.html";
$cssfile = "logrep.css";

# Generates stylesheet for web pages
GenerateCSSFile ();

# WriteIndexPage
open HTMLPAGE, "> $webdir/$indexpage" or die $dieopenmsg;
PrintHtmlHeader (HTMLPAGE);

##################
# Generate HTML code for favorite graphs
#
print HTMLPAGE	$q->div ({align=>"center"}, $q->h3 ("Favorite graphs") );

my $ngraph = 0;
print HTMLPAGE '<div align="center"><table border="1" bordercolor="#800000">';

foreach (@favoriteGraphs) {

	print HTMLPAGE "<tr>" if (($ngraph % 2) == 0);
	
	my $sysname = $favoriteGraphs[$ngraph][0];
	my $ipadr = $favoriteGraphs[$ngraph][1];
	my $img = "$sysname/" . $favoriteGraphs[$ngraph][2] . ".png";

	print HTMLPAGE
		$q->td (
			$q->strong (
				$q->font ( {size=>"+1"},
					"$sysname - $ipadr"
				),
				$q->br,
				$q->img ({src=>"$img"})
			)
		);
	
	$ngraph++;
	
	print HTMLPAGE "</tr>" if (($ngraph % 2) == 0);
	
}	
		
print HTMLPAGE "</table></div>";
print HTMLPAGE	$q->p ( $q->hr );	

###############
# Generate HTML code for favorite reports
#
print HTMLPAGE $q->div ({align=>"center"},	$q->h3 ("Favorite reports")	);

my $nreport = 0;
print HTMLPAGE '<div align="center"><table border="1" width="800">';

foreach (@favoriteReports) {

	print HTMLPAGE "<tr>" if (($nreport % 4) == 0);
	
	my $sysname = $favoriteReports[$nreport][0];
	my $ipadr = $favoriteReports[$nreport][1];
	my $reportbase = ucfirst($favoriteReports[$nreport][2]) . "-" . ucfirst($favoriteReports[$nreport][3]);
	my $report = "$sysname/$ipadr/$mode/" . $reportbase . "-x.html";

	print HTMLPAGE
		$q->td (
			$q->div ({align=>"center"},	"$sysname - $ipadr"),
			$q->br,
			$q->div ( {align=>"center"}, $q->strong ( $q->a ({href=>"$report"}, $reportbase)))
		);
	
	$nreport++;
	
	print HTMLPAGE "</tr>" if (($nreport % 4) == 0);
	
}	
		
print HTMLPAGE "</table></div>";
print HTMLPAGE	$q->p ( $q->hr );

############
# Generate HTML code for all nodes
#

print HTMLPAGE	$q->div ({align=>"center"}, $q->h3 ("All nodes") );

my $nnodes = 0;
print HTMLPAGE '<div align="center"><table border="1" width="800">';

foreach (@nodes) {

	print HTMLPAGE "<tr>" if (($nnodes % 4) == 0);
	
	my $sysname = $nodes [$nnodes][0];
	my $ipadr = $nodes [$nnodes][1];
	my $nodebase = "$sysname/$ipadr/$mode/index.html";

	print HTMLPAGE
		$q->td (
			$q->strong (
				$q->a ({href=>"$nodebase"}, "$sysname - $ipadr")
			)
		);
	
	$nnodes++;
	
	print HTMLPAGE "</tr>" if (($nnodes % 4) == 0);
		
}	
		
print HTMLPAGE "</table></div>";
print HTMLPAGE	$q->p ( $q->hr );

print HTMLPAGE $q->end_html;
	
close HTMLPAGE or die $dieclosemsg;

