#############################################################################
#
# LOGREP - Logfile Extraction And Reporting System                          
# Copyright (C) 2002 Tevfik Karaglle                                   
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
#
#############################################################################

#########
#
# Exchange module for log reporting system
# v1.0 - Initial version, Nov 2002, Tevfik K. (tevfik@itefix.no)

# Sets analysis parameters - specific for each module
@dim = ( "month", "day", "hour", "gateway", "from", "priority", "sizeKB", "to");

# Get common functions & parameters
do "lib1.pl";

################
# MAIN PROGRAM #
################

SetCommonParameters ();

# initialize counters
$n = $nmessages = 0;

ProcessExchangeFile ($logfilename);

WriteIndexPage (
	"Exchange Tracking log analysis",
	"Message Analysis Table",
	"Number of messages processed: ", "$nmessages"
	);

WriteDetailsPages ();

###############
# SUBROUTINES #
###############

# ProcessExchangeFile : 
#	Processes Exchange 5.5 tracking log and populates counter arrays
#	Parameter : filename
#
sub ProcessExchangeFile {

	my $logfile = shift;
	
	open LOGFILE, $logfile or die $dieopenmsg;

LOOP: 
	while (<LOGFILE>) {

		next if !/\t/; # Start with a TAB delimited line

		my $line = $_;

		($month, $day, $hour, $minute, $gateway, $from, $priority, $size, $recipients ) =		 
			($line =~ m![^\t]*\t\d+\t\d+\.(\d+)\.(\d+) (\d+):(\d+):\d+\t([^\t]*)\t[^\t]*\t[^\t]*\t([^\t]*)\t(\S+)\t(\d+)\t[^\t]*\t[^\t]*\t[^\t]*\t(\d+)!);

		($startdate = "$month/$day $hour:$minute") if ($. == 1);
		
		$sizeKB = int ($size / 1024);

		# Only last recipient address is kept in $to field!!
		for (my $i = 0; $i < $recipients; $i++) {

			$to = <LOGFILE>;
		}

		$nmessages++;

		#DEBUG! print "$month, $day, $hour, $minute, $gateway, $from, $priority, $sizeKB, $recipients, $to\n";

		print "$. - $hour:$minute $from\n" if ($month eq "");
		
		GenerateTables ();
	}
	
	$enddate = "$month/$day $hour:$minute";

	$n = $.;
	
	close LOGFILE or die $dieclosemsg;
}
