#############################################################################
#
# LOGREP - Logfile Extraction And Reporting System                          
# Copyright (C) 2002 Tevfik Karaglle                                   
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
#
#############################################################################

#########
#
# Checkpoint Firewall-1 module for log reporting system
# v1.0 - Initial version, Oct 2002, Tevfik K. (www.itefix.no)
 
# Sets analysis parameters - specific for each module
@dim = ( "month", "day", "hour", "originator", "type", "action", "alert", "interface", "direction", "protocol", "source", "destination", "service", "rule", "length");

# Get common functions & parameters
do "lib1.pl";

################
# MAIN PROGRAM #
################

SetCommonParameters ();

# initialize counters
$n = $nalert = 0;

ProcessFirewall1LogFile ($logfilename);

WriteIndexPage (
	"Checkpoint Firewall-1 Logfile analysis",
	"Log Analysis Table",
	"Number of alerts: ", "$nalert"
	);

WriteDetailsPages ();

###############
# SUBROUTINES #
###############

# ProcessFirewall1LogFile : 
#	Processes Firewall-1 export logfile and populates counter arrays
#	Parameter : Firewall-1 export log filename
#
sub ProcessFirewall1LogFile {

	my $logfile = shift;
		
	open LOGFILE, $logfile or die $dieopenmsg;

	<LOGFILE>; # Skip over first header line

LOOP: 
	while (<LOGFILE>) {
		
		my $line = $_;

		($day, $monthmmm, $hour, $minute, $originator, $type, $action, $alert, $interface, $direction, $protocol, $source, $destination, $service, $rule, $reason, $length) = 
			($line =~ /\d+;(\d+)(\w\w\w)\d+;([^:]+):(\d\d):\d\d;([^;]+);([^;]+);([^;]+);([^;]*);([^;]+);([^;]+);[^;]+;[^;]*;[^;]*;([^;]*);([^;]*);([^;]*);([^;]*);[^;]*;([^;]*);([^;]*);[^;]*;[^;]*;([^;]*)/);
			
		# Some normalization
		$month = $monthnr {$monthmmm};
		
		($startdate = "$month/$day $hour:$minute") if ($. == 2); # first line was a header!

		#DEBUG! print "$num, $month, $day, $hour, $minute, $originator, $type, $action, $alert, $interface, $direction, $protocol, $source, $destination, $service, $rule, $reason, $length\n\n";
		
		$nalert++ if ($alert ne "");
		
		GenerateTables ();
						
	}
	
	$enddate = "$month/$day $hour:$minute";

	$n = $.;
	
	close LOGFILE or die $dieclosemsg;
}

