#############################################################################
#
# LOGREP - Logfile Extraction And Reporting System                          
# Copyright (C) 2002 Tevfik Karaglle                                   
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
#
#############################################################################

#########
#
# Cisco Pix module for log reporting system
# v1.0 - Initial version, Nov 2002, Tevfik K. (tevfik@itefix.no)

# Sets analysis parameters - specific for each module

@dim = (

	"month", "day", "hour", "pixnode", "severity", "source", "sourceport", "destination", "destport", "event"
);

# Get common functions & parameters
do "lib1.pl";

################
# MAIN PROGRAM #
################

SetCommonParameters ();

# initialize counters
$n = 0;

@sevcount = (0, 0, 0, 0, 0);

ProcessPixFile ($logfilename);

WriteIndexPage (
	"PIX message analysis",
	"Message Analysis Table",
	"(Alert, Critical, Error, Warning) =", "($sevcount[1], $sevcount[2], $sevcount[3], $sevcount[4])"
	);

WriteDetailsPages ();

###############
# SUBROUTINES #
###############

# ProcessPixFile : 
#	Processes Pix logfile and populates counter arrays
#	Parameter : filename
#
sub ProcessPixFile {

	my $logfile = shift;
	
	open LOGFILE, $logfile or die $dieopenmsg;

LOOP: 
	while (<LOGFILE>) {

		next if !/%PIX/; # Only Pix lines !!

		my $line = $_;

		($monthmmm, $day, $hour, $minute, $pixnode, $severity, $code, $message ) =		 
			($line =~ m!(\S+)\s+(\d+)\s+(\d\d):(\d\d):\d\d\s+(\S*).+%PIX-(\d)-(\d+):(.*)!) ;

		# Some normalization
		$month = $monthnr {$monthmmm}; # Month number
		$source = $sourceport = $destination = $destport = $flags = $event = "";
		
		$msghead = $msgend = "";
		
		# Decoding level alert (level 1) and critical messages (level 2)
		
		($sevcount[$severity]++) if ($severity >= 1 && $severity <= 4);
		
	MSGPARSE: {
        	if (($code == 106001) || ($code == 106006) || ($code == 106007) ) {
        		($msghead, $source, $sourceport, $destination, $destport, $msgend) = 
        			($message =~ m!(.*) from (\S+)/(\S+) to (\S+)/(\S+) (.*)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}
 
        	if ($code == 106002) {
        		($msghead, $source, $sourceport, $destination, $destport) = 
        			($message =~ m!(.*) src (\S+) (\S+) dest (\S+) (\S+)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}
        	
        	if ($code == 106003) {
        		($msghead, $source, $destination, $msgend) = 
        			($message =~ m!(.*) src (\S+) dest (\S+) (.*)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}
        	
        	if ($code == 106009) {
        		($msghead, $source, $destination, $destport, $msgend, $sourceport) = 
        			($message =~ m!(.*) for (\S+) to (\S+)/(\S+) (\S+ \S+ \S+ \S+ \S+ \S+) (\S+)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}

			if ($code == 106012) {
        		($msghead, $source, $destination, $msgend) = 
        			($message =~ m!(.*) from (\S+) to (\S+)(.*)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}

			if ($code == 106013) {
        		($msghead, $source, $destination, $msgend) = 
        			($message =~ m!(.*) from (\S+) to PAT address (\S+)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}

        	if ($code == 106016) {
        		($msghead, $source, $destination, $msgend) = 
        			($message =~ m!(.*) from (\S+) to (\S+)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}

			if ($code == 106017) {
        		($msghead, $source, $destination, $msgend) = 
        			($message =~ m!(.*) src (\S+) dest to (\S+)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}

			if ($code == 106018) {
        		($msghead, $source, $destination, $msgend) = 
        			($message =~ m!(.*) src (\S+) dest (\S+)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}
        	
        	if ($code == 108002) {
        		($msghead, $source) = 
        			($message =~ m!(.*) out (\S+)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}

        	if ($code == 109011) {
        		($msghead) = 
        			($message =~ m!(.*) user!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}

			if ($code == 112001) {
        		($msgend) = 
        			($message =~ m!.* (pix .*)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}

  			if ($code == 201003) {
        		($msghead) = 
        			($message =~ m!(.*) for!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}

  			if ($code == 304007) {
        		($msghead, $source, $msgend) = 
        			($message =~ m!(URL Server) (\S+) (.*)!);
        		$event = "$code: $msghead $msgend";
        		last MSGPARSE;
        	}

			($message = substr $message, 1, 40) if ($severity > 2);
			 
			$event = "$code: $message";
   
    	}
				
		($startdate = "$month/$day $hour:$minute") if ($. == 1);

		#DEBUG!	print "$month, $day, $hour, $minute, $pixnode, $severity, $source, $sourceport, $destination, $destport, $event\n";
		
		GenerateTables ();
	}
	
	$enddate = "$month/$day $hour:$minute";

	$n = $.;
	
	close LOGFILE or die $dieclosemsg;
}
