#############################################################################
#
# LOGREP - Logfile Extraction And Reporting System                          
# Copyright (C) 2002 Tevfik Karaglle                                   
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
#
#############################################################################

#########
#
# Squid module for log reporting system
# v1.0 - Initial version, 06.2002, Tevfik K. (www.itefix.no)

# Sets analysis parameters - specific for each module
@dim = ( "month", "day", "hour", "elapsed", "from", "cache", "result", "size", "method", "url", "content");

# Get common functions & parameters
do "lib1.pl";

################
# MAIN PROGRAM #
################

SetCommonParameters ();

ProcessSquidLogFile ($logfilename);

WriteIndexPage (
	"SQUID Logfile analysis",
	"Cache Analysis Table"
	);

WriteDetailsPages ();

###############
# SUBROUTINES #
###############

# ProcessSquidLogFile : 
#	Processes squid logfile and populates counter arrays
#	Parameter : squid log filename
#
sub ProcessSquidLogFile {

	my $logfile = shift;
		
	open LOGFILE, $logfile or die $dieopenmsg;

LOOP: 
	while (<LOGFILE>) {

		my $line = $_;
		
		($timetag, $elapsed, $from, $cache, $result, $size, $method, $fullurl, $content) = 
			($line =~ m"([\d\.]+)\s+(\d+) ([\d\.]+) (\w+)/(\d+) (\d+) (\w+) (\S+) \S+ \S+ (\S+)");

		# extract time info
		($tmp, $minute, $hour, $day, $month, $tmp, $tmp, $tmp) = gmtime ($timetag);

		# parse full url
		($tmp, $tmp, $url) = split (m"/", $fullurl);
		
		# elapsed time in integer seconds
		$elapsed = int ($elapsed / 1000);
		
		# size in integer KB
		$size = int ($size / 1024);
				
		($startdate = "$month/$day $hour:$minute") if ($. == 1);
		
		#DEBUG!	print "$day, $month, $hour, $elapsed, $from, $cache, $result, $size, $method, $url, $content\n";
		
		GenerateTables ();
	}
	
	$enddate = "$month/$day $hour:$minute";

	$n = $.;
	
	close LOGFILE or die $dieclosemsg;
}
